==> nextcloud-23.0.8.tgz: nextcloud/apps/circles/l10n/sr.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Кругови",
    "Circles' files" : "Фајлови од круга",
    "Select circles to filter by" : "Одаберите кругове по којима да се филтрира",
    "No circles found" : "Није нађен ниједан круг",
    "Please select circles to filter by" : "Молимо одаберите кругове по којима да се филтрира",
    "No files found for the selected circles" : "Ниједан фајл није нађен за одабране кругове",
    "You created the circle {circle}" : "Направили сте круг {circle}",
    "{author} created the circle {circle}" : "{author} је направио круг {circle}",
    "You deleted {circle}" : "Обрисали сте круг {circle}",
    "{author} deleted {circle}" : "{author} је обрисао круг {circle}",
    "You linked {group} to {circle}" : "Везали сте групу {group} на круг {circle}",
    "{group} has been linked to {circle} by {author}" : "{author} је повезао групу {group} са кругом {circle}",
    "You unlinked {group} from {circle}" : "Одвезали сте групу {group} од круга {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{author} је одвезао групу {group} од круга {circle}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Променили сте ниво везе групе {group} у кругу {circle} на %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} је променио ниво везе групе {group} у кругу {circle} на %1$s",
    "You sent a request to link {circle} with {remote}" : "Послали сте захтев да вежете круг {circle} са {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} је послао захтев да веже круг {circle} са {remote}",
    "{remote} requested a link with {circle}" : "{remote} је захтевао везивање са кругом {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Захтев за везивањем круга {circle} са {remote} је одбијен",
    "The request to link {remote} with {circle} has been canceled remotely" : "Захтев за везивањем круга {circle} са {remote} је поништен са друге стране",
    "The request to link {circle} with {remote} has been accepted" : "Захтев за везивањем круга {circle} са {remote} је прихваћен",
    "You dismissed the request to link {remote} with {circle}" : "Одбацили сте захтев за везивањем {remote} са кругом {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} је одбацио захтев за везивање {remote} са кругом {circle}",
    "You canceled the request to link {circle} with {remote}" : "Поништили сте захтев за везивањем круга {circle} саwith {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} је поништио захтев за везивањем круга {circle} са {remote}",
    "You accepted the request to link {remote} with {circle}" : "Прихватили сте захтев за везивањем {remote} са кругом {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} је прихватио захтев за везивањем {remote} са кругом {circle}",
    "A link between {circle} and {remote} is now up and running" : "Веза између круга  {circle} и {remote} је успостављена и ради",
    "The link between {circle} and {remote} has been shutdown remotely" : "Веза између круга  {circle} и {remote} је угашена са друге стране",
    "You closed the link between {circle} and {remote}" : "Затворили сте везу између круга {circle} и {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} је затворио везу између круга {circle} и {remote}",
    "You joined {circle}" : "Придружили сте се кругу {circle}",
    "{member} joined {circle}" : "{member} се придружио кругу {circle}",
    "You accepted the invitation to join {circle}" : "Прихватили сте позив да се придружите кругу {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} је прихватио позив да се придружи кругу {circle}",
    "You added {member} as member to {circle}" : "Додали сте корисника {member} као члана у круг {circle}",
    "You have been added as member to {circle} by {author}" : "{author} Вас је додао као члана у круг {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} је додао корисника {member} у круг {circle}",
    "You added {external} to {circle}" : "Додали сте {external} у круг {circle}",
    "{external} has been added to {circle} by {author}" : "{author} је додао {external} у круг{circle}",
    "You accepted {member}'s request to join {circle}" : "Прихватили сте захтев корисника {member} да се придружите кругу {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} је прихватио Ваш позив да се придружите кругу {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} је прихватио захтев корисника {member} да се придружи кругу {circle} ",
    "You left {circle}" : "Напустили сте круг {circle}",
    "{member} left {circle}" : "{member} је напустио круг {circle}",
    "You declined the invitation to join {circle}" : "Одбили сте позивницу да се придружите кругу {circle}",
    "{member} declined an invitation to join {circle}" : "{member} је одбио позивницу да се придружи кругу {circle}",
    "You cancelled your request to join {circle}" : "Отказали сте захтев да се придружите кругу {circle}",
    "{member} cancelled his request to join {circle}" : "{member} је отказао захтев да се придружи кругу {circle}",
    "You removed {member} from {circle}" : "Уклонили сте корисника {member} из круга {circle}",
    "You have been removed from {circle} by {author}" : "{author} Вас је уклонио из круга {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} је уклонио корисника {member} из круга {circle}",
    "You removed {external} from {circle}" : "Уклонили сте {external} из круга {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} је уклонио {external} из круга {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Отказали сте позивницу кориснику {member} да се придружи кругу {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} је поништио Вашу позивницу да се придружите кругу {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} је поништио позивницу корисника {member} да се придружи кругу {circle}",
    "You dismissed {member}'s request to join {circle}" : "Одбацили сте захтев корисника {member} да се придружи кругу {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} је одбацио Ваш захтев да се придружите кругу {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} је одбацио захтев корисника {member} да се придружи кругу {circle}",
    "You invited {member} to join {circle}" : "Позвали сте корисника {member} да се придружи кругу {circle}",
    "You have been invited to join {circle} by {author}" : "{author} Вас је позвао да се придружите кругу {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} је позвао корисника {member} да се придружи кругу {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Променили сте ниво корисника {member} у кругу {circle} на %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} је променио Ваш ниво у кругу {circle} на %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} је променио ниво корисника {member} у кругу {circle} на %1$s",
    "You sent a request to join {circle}" : "Послали сте захтев да се придружите кругу {circle}",
    "{member} sent a request to join {circle}" : "{member} је послао захтев да се придружи кругу {circle}",
    "You are the new owner of {circle}" : "Ви сте нови власник круга {circle}",
    "{member} is the new owner of {circle}" : "{member} је нови власник круга {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "На догађаје који се дешавају у <strong>Кругу</strong> чији сте члан",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Било који битан догађај у <strong>Кругу</strong> који модеришете",
    "On global events happening in any <strong>Circle</strong>" : "На јавне догађаје који се дешавају и било ком <strong>кругу</strong>",
    "Personal" : "Лични",
    "System" : "Систем",
    "Visible" : "Видљив",
    "Open" : "Отвори",
    "Hidden" : "Сакривен",
    "Local" : "Локално",
    "Root" : "Корен",
    "Federated" : "Здружено",
    "Contact" : "Контакт",
    "Circle" : "Круг",
    "Member" : "Члан",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Власник",
    "%s shared »%s« with you." : "%s је поделио »%s« са Вама.",
    "%s on %s" : "%s на %s",
    "Password to access »%1$s« shared to you by %2$s" : "%2$s Вам је поделио/ла лозинку за приступ „%1$s“",
    "Password to access »%s«" : "Лозинка за приступ „%s“",
    "It is protected with the following password:" : "Заштићена је следећом лозинком:",
    "%1$s via %2$s" : "%1$s преко %2$s",
    "Click the button below to open it." : "Кликните дугме испод да га отворите.",
    "Open »%s«" : "Отвори »%s«",
    "Password to access files shared to you by %1$s" : "Лозинка да приступите фајлова које Вам је поделио %1$s",
    "Password to access files" : "Лозинка за приступ фајловима",
    "%s shared multiple files with you." : "%s је поделио више фајлова са Вама.",
    "Circle not found" : "Круг није нађен",
    "Circle not found " : "Криг није нађен",
    "A circle with that name exists" : "Круг са тим именом постоји",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Не можете користити апликацију Кругови док администратор не дозволи бар један тип кругова",
    "This member does not exist" : "Члан не постоји",
    "This user is already a member of the circle" : "Корисник је већ члан круга",
    "Federated link not found" : "Здружена веза није нађена",
    "This feature is not available for personal circles" : "Ова функционалност није доступна за личне кругове",
    "The circle is not federated" : "Круг није здружен",
    "You cannot join this circle" : "Не можете се придружити кругу",
    "This member is not a moderator" : "Овај члан није модератор",
    "Insufficient privileges" : "Недовољне дозволе",
    "This member is the owner of the circle" : "Овај члан је власник круга",
    "Level cannot be changed for this type of member" : "Ниво не може да се промени за овај тип члана",
    "You are already a member of this circle" : "Већ сте члан овог круга",
    "You have been blocked from this circle" : "Блокирани сте у овом кругу",
    "The user is already a member of this circle" : "Корисник је већ члан круга",
    "The user has already been invited into this circle" : "Корисник је већ позван у овај круг",
    "You are now a member of the Circle \"%2$s\"" : "Сада сте члан круга „%2$s“",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s Вас је позвао/ла у круг „%2$s“",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s је послао захтев да буде члан круга „%2$s“",
    "Accept" : "Прихвати",
    "Refuse" : "Одбиј",
    "Leave the circle" : "Напусти круг",
    "%s" : "%s",
    "Personal Circle" : "Лични круг",
    "You need a specify a type of circle" : "Морате навести тип круга",
    "This member is not the owner of the circle" : "Овај члан није власник круга",
    "This member is not an admin of the circle" : "Овај члан није администратор круга",
    "Group contains too many members" : "Група садржи превише чланова",
    "This group does not exist" : "Ова група не постоји",
    "This group is already linked to the circle" : "Ова група је већ везана за круг",
    "You cannot edit level in a personal circle" : "Не можете мењати ниво у личним круговима",
    "Group cannot be set as owner of a circle" : "Не можете да поставите групу као власника круга",
    "now" : "сада",
    "This user does not exist" : "Овај корисник не постоји",
    "Email format is not valid" : "Формат адресе е-поште није исправан",
    "This contact is not available" : "Овај контакт није доступан",
    "Could not find share" : "Не могу да нађем дељење",
    "Bring cloud-users closer together." : "Приближимо клауд кориснике.",
    "No files in here" : "Овде нема фајлова",
    "No entries found in this folder" : "Нема резултата у овој фасцикли",
    "Name" : "Назив",
    "Size" : "Величина",
    "Modified" : "Измењен"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-24.0.10.tgz: nextcloud/apps/circles/l10n/sr.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Кругови",
    "Circles' files" : "Фајлови од круга",
    "Select circles to filter by" : "Одаберите кругове по којима да се филтрира",
    "No circles found" : "Није нађен ниједан круг",
    "Please select circles to filter by" : "Молимо одаберите кругове по којима да се филтрира",
    "No files found for the selected circles" : "Ниједан фајл није нађен за одабране кругове",
    "You created the circle {circle}" : "Направили сте круг {circle}",
    "{author} created the circle {circle}" : "{author} је направио круг {circle}",
    "You deleted {circle}" : "Обрисали сте круг {circle}",
    "{author} deleted {circle}" : "{author} је обрисао круг {circle}",
    "You linked {group} to {circle}" : "Везали сте групу {group} на круг {circle}",
    "{group} has been linked to {circle} by {author}" : "{author} је повезао групу {group} са кругом {circle}",
    "You unlinked {group} from {circle}" : "Одвезали сте групу {group} од круга {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{author} је одвезао групу {group} од круга {circle}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Променили сте ниво везе групе {group} у кругу {circle} на %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} је променио ниво везе групе {group} у кругу {circle} на %1$s",
    "You sent a request to link {circle} with {remote}" : "Послали сте захтев да вежете круг {circle} са {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} је послао захтев да веже круг {circle} са {remote}",
    "{remote} requested a link with {circle}" : "{remote} је захтевао везивање са кругом {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Захтев за везивањем круга {circle} са {remote} је одбијен",
    "The request to link {remote} with {circle} has been canceled remotely" : "Захтев за везивањем круга {circle} са {remote} је поништен са друге стране",
    "The request to link {circle} with {remote} has been accepted" : "Захтев за везивањем круга {circle} са {remote} је прихваћен",
    "You dismissed the request to link {remote} with {circle}" : "Одбацили сте захтев за везивањем {remote} са кругом {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} је одбацио захтев за везивање {remote} са кругом {circle}",
    "You canceled the request to link {circle} with {remote}" : "Поништили сте захтев за везивањем круга {circle} саwith {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} је поништио захтев за везивањем круга {circle} са {remote}",
    "You accepted the request to link {remote} with {circle}" : "Прихватили сте захтев за везивањем {remote} са кругом {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} је прихватио захтев за везивањем {remote} са кругом {circle}",
    "A link between {circle} and {remote} is now up and running" : "Веза између круга  {circle} и {remote} је успостављена и ради",
    "The link between {circle} and {remote} has been shutdown remotely" : "Веза између круга  {circle} и {remote} је угашена са друге стране",
    "You closed the link between {circle} and {remote}" : "Затворили сте везу између круга {circle} и {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} је затворио везу између круга {circle} и {remote}",
    "You joined {circle}" : "Придружили сте се кругу {circle}",
    "{member} joined {circle}" : "{member} се придружио кругу {circle}",
    "You accepted the invitation to join {circle}" : "Прихватили сте позив да се придружите кругу {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} је прихватио позив да се придружи кругу {circle}",
    "You added {member} as member to {circle}" : "Додали сте корисника {member} као члана у круг {circle}",
    "You have been added as member to {circle} by {author}" : "{author} Вас је додао као члана у круг {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} је додао корисника {member} у круг {circle}",
    "You added {external} to {circle}" : "Додали сте {external} у круг {circle}",
    "{external} has been added to {circle} by {author}" : "{author} је додао {external} у круг{circle}",
    "You accepted {member}'s request to join {circle}" : "Прихватили сте захтев корисника {member} да се придружите кругу {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} је прихватио Ваш позив да се придружите кругу {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} је прихватио захтев корисника {member} да се придружи кругу {circle} ",
    "You left {circle}" : "Напустили сте круг {circle}",
    "{member} left {circle}" : "{member} је напустио круг {circle}",
    "You declined the invitation to join {circle}" : "Одбили сте позивницу да се придружите кругу {circle}",
    "{member} declined an invitation to join {circle}" : "{member} је одбио позивницу да се придружи кругу {circle}",
    "You cancelled your request to join {circle}" : "Отказали сте захтев да се придружите кругу {circle}",
    "{member} cancelled his request to join {circle}" : "{member} је отказао захтев да се придружи кругу {circle}",
    "You removed {member} from {circle}" : "Уклонили сте корисника {member} из круга {circle}",
    "You have been removed from {circle} by {author}" : "{author} Вас је уклонио из круга {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} је уклонио корисника {member} из круга {circle}",
    "You removed {external} from {circle}" : "Уклонили сте {external} из круга {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} је уклонио {external} из круга {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Отказали сте позивницу кориснику {member} да се придружи кругу {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} је поништио Вашу позивницу да се придружите кругу {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} је поништио позивницу корисника {member} да се придружи кругу {circle}",
    "You dismissed {member}'s request to join {circle}" : "Одбацили сте захтев корисника {member} да се придружи кругу {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} је одбацио Ваш захтев да се придружите кругу {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} је одбацио захтев корисника {member} да се придружи кругу {circle}",
    "You invited {member} to join {circle}" : "Позвали сте корисника {member} да се придружи кругу {circle}",
    "You have been invited to join {circle} by {author}" : "{author} Вас је позвао да се придружите кругу {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} је позвао корисника {member} да се придружи кругу {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Променили сте ниво корисника {member} у кругу {circle} на %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} је променио Ваш ниво у кругу {circle} на %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} је променио ниво корисника {member} у кругу {circle} на %1$s",
    "You sent a request to join {circle}" : "Послали сте захтев да се придружите кругу {circle}",
    "{member} sent a request to join {circle}" : "{member} је послао захтев да се придружи кругу {circle}",
    "You are the new owner of {circle}" : "Ви сте нови власник круга {circle}",
    "{member} is the new owner of {circle}" : "{member} је нови власник круга {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "На догађаје који се дешавају у <strong>Кругу</strong> чији сте члан",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Било који битан догађај у <strong>Кругу</strong> који модеришете",
    "On global events happening in any <strong>Circle</strong>" : "На јавне догађаје који се дешавају и било ком <strong>кругу</strong>",
    "Personal" : "Лични",
    "System" : "Систем",
    "Visible" : "Видљив",
    "Open" : "Отвори",
    "Hidden" : "Сакривен",
    "Local" : "Локално",
    "Root" : "Корен",
    "Federated" : "Здружено",
    "Contact" : "Контакт",
    "Circle" : "Круг",
    "Member" : "Члан",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Власник",
    "%s shared »%s« with you." : "%s је поделио »%s« са Вама.",
    "%s on %s" : "%s на %s",
    "Password to access »%1$s« shared to you by %2$s" : "%2$s Вам је поделио/ла лозинку за приступ „%1$s“",
    "Password to access »%s«" : "Лозинка за приступ „%s“",
    "It is protected with the following password:" : "Заштићена је следећом лозинком:",
    "%1$s via %2$s" : "%1$s преко %2$s",
    "Click the button below to open it." : "Кликните дугме испод да га отворите.",
    "Open »%s«" : "Отвори »%s«",
    "Password to access files shared to you by %1$s" : "Лозинка да приступите фајлова које Вам је поделио %1$s",
    "Password to access files" : "Лозинка за приступ фајловима",
    "%s shared multiple files with you." : "%s је поделио више фајлова са Вама.",
    "Circle not found" : "Круг није нађен",
    "Circle not found " : "Криг није нађен",
    "This member does not exist" : "Члан не постоји",
    "Federated link not found" : "Здружена веза није нађена",
    "This feature is not available for personal circles" : "Ова функционалност није доступна за личне кругове",
    "The circle is not federated" : "Круг није здружен",
    "You cannot join this circle" : "Не можете се придружити кругу",
    "This member is not a moderator" : "Овај члан није модератор",
    "Insufficient privileges" : "Недовољне дозволе",
    "This member is the owner of the circle" : "Овај члан је власник круга",
    "Level cannot be changed for this type of member" : "Ниво не може да се промени за овај тип члана",
    "You are already a member of this circle" : "Већ сте члан овог круга",
    "You have been blocked from this circle" : "Блокирани сте у овом кругу",
    "You are now a member of the Circle \"%2$s\"" : "Сада сте члан круга „%2$s“",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s Вас је позвао/ла у круг „%2$s“",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s је послао захтев да буде члан круга „%2$s“",
    "Accept" : "Прихвати",
    "Refuse" : "Одбиј",
    "Leave the circle" : "Напусти круг",
    "%s" : "%s",
    "Personal Circle" : "Лични круг",
    "You need a specify a type of circle" : "Морате навести тип круга",
    "A circle with that name exists" : "Круг са тим именом постоји",
    "This member is not the owner of the circle" : "Овај члан није власник круга",
    "This member is not an admin of the circle" : "Овај члан није администратор круга",
    "Group contains too many members" : "Група садржи превише чланова",
    "This group does not exist" : "Ова група не постоји",
    "This group is already linked to the circle" : "Ова група је већ везана за круг",
    "You cannot edit level in a personal circle" : "Не можете мењати ниво у личним круговима",
    "Group cannot be set as owner of a circle" : "Не можете да поставите групу као власника круга",
    "now" : "сада",
    "Email format is not valid" : "Формат адресе е-поште није исправан",
    "This contact is not available" : "Овај контакт није доступан",
    "Bring cloud-users closer together." : "Приближимо клауд кориснике.",
    "No files in here" : "Овде нема фајлова",
    "No entries found in this folder" : "Нема резултата у овој фасцикли",
    "Name" : "Назив",
    "Size" : "Величина",
    "Modified" : "Измењен",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Не можете користити апликацију Кругови док администратор не дозволи бар један тип кругова",
    "This user is already a member of the circle" : "Корисник је већ члан круга",
    "The user is already a member of this circle" : "Корисник је већ члан круга",
    "The user has already been invited into this circle" : "Корисник је већ позван у овај круг",
    "This user does not exist" : "Овај корисник не постоји",
    "Could not find share" : "Не могу да нађем дељење"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
